@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '3.0.1';
+our $VERSION = '3.0.2';
 
 use Carp              ();
 use File::Spec        ();
@@ -524,7 +524,7 @@ sub _load_compiled {
         }
         elsif($c->[0] eq 'literal') {
             # force upgrade to avoid UTF-8 key issues
-            utf8::upgrade($c->[1]);
+            utf8::upgrade($c->[1]) if($is_utf8);
         }
         push @asm, $c;
     }
@@ -661,7 +661,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 3.0.1.
+This document describes Text::Xslate version 3.0.2.
 
 =head1 SYNOPSIS
 
